==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/emoticons/translations/emoticons_es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX">
<context>
    <name>@default</name>
    <message>
        <source>default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <source>Icons</source>
        <translation>Iconos</translation>
    </message>
    <message>
        <source>Emoticons</source>
        <translation>Emoticonos</translation>
    </message>
    <message>
        <source>Enable emoticons</source>
        <translation>Habilitar emoticonos</translation>
    </message>
    <message>
        <source>Animate emoticons</source>
        <translation>Animar emoticonos</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Tema de iconos</translation>
    </message>
    <message>
        <source>Choose emoticons theme</source>
        <translation>Elegir tema de emoticonos</translation>
    </message>
    <message>
        <source>Install new emoticons...</source>
        <translation>Instalar nuevos emoticonos...</translation>
    </message>
</context>
<context>
    <name>EmoticonsConfigurationUiHandler</name>
    <message>
        <source>Open icon theme archive</source>
        <translation>Abrir archivo de tema de iconos</translation>
    </message>
    <message>
        <source>Installation failed</source>
        <translation>Error en la instalación</translation>
    </message>
    <message>
        <source>Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</source>
        <translation>Archivo (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</translation>
    </message>
</context>
<context>
    <name>InsertEmoticonAction</name>
    <message>
        <source>Insert Emoticon</source>
        <translation>Insertar Emoticon</translation>
    </message>
    <message>
        <source>Insert emoticon</source>
        <translation>Insertar emoticon</translation>
    </message>
    <message>
        <source>Insert emoticon - enable in configuration</source>
        <translation>Insertar emoticon - habilitar en configuración</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/emoticons/translations/emoticons_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <source>Icons</source>
        <translation>Iconos</translation>
    </message>
    <message>
        <source>Emoticons</source>
        <translation>Emoticonos</translation>
    </message>
    <message>
        <source>Enable emoticons</source>
        <translation>Habilitar emoticonos</translation>
    </message>
    <message>
        <source>Animate emoticons</source>
        <translation>Animar emoticonos</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Tema de iconos</translation>
    </message>
    <message>
        <source>Choose emoticons theme</source>
        <translation>Elegir tema de emoticonos</translation>
    </message>
    <message>
        <source>Install new emoticons...</source>
        <translation>Instalar nuevos emoticonos...</translation>
    </message>
</context>
<context>
    <name>EmoticonsConfigurationUiHandler</name>
    <message>
        <source>Open icon theme archive</source>
        <translation>Abrir archivo de tema de iconos</translation>
    </message>
    <message>
        <source>Installation failed</source>
        <translation>Error en la instalación</translation>
    </message>
    <message>
        <source>Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</source>
        <translation>Archivo (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</translation>
    </message>
</context>
<context>
    <name>InsertEmoticonAction</name>
    <message>
        <source>Insert Emoticon</source>
        <translation>Insertar Emoticon</translation>
    </message>
    <message>
        <source>Insert emoticon</source>
        <translation>Insertar emoticon</translation>
    </message>
    <message>
        <source>Insert emoticon - enable in configuration</source>
        <translation>Insertar emoticon - habilitar en configuración</translation>
    </message>
</context>
</TS>
